@@ -168,6 +168,8 @@ class Canvas(tk.Canvas, Scrollable):
         Return None if not Found
         """
         items = self.find_overlapping(xc - 1, yc - 1, xc + 1, yc + 1)
+        if self.lastItem is not None and self.lastItem.id in items:
+            return self.lastItem
         for i in items:
             if i in self.items:
                 return self.items[i]
@@ -385,11 +387,18 @@ class Canvas(tk.Canvas, Scrollable):
 
         if layout is not None:
             layout.draw(graph)
+            # Update node positions
+            self._updatePositions(graph.getRoot(), {})
 
+        self.updateScrollRegion()
+        self.__zoom(None, scale)
+
+    def reorganizeGraph(self, graph, layout=None):
+
+        layout.draw(graph)
         # Update node positions
         self._updatePositions(graph.getRoot(), {})
         self.updateScrollRegion()
-        self.__zoom(None, scale)
 
     def _drawNode(self, canvas, node):
         """ Default implementation to draw nodes as textboxes. """
@@ -410,6 +419,7 @@ class Canvas(tk.Canvas, Scrollable):
             if getattr(node, 'expanded', True):
                 for child in node.getChilds():
                     self._drawNodes(child, visitedDict)
+                    self.createEdge(item, child.item)
             else:
                 self._setupParentProperties(node, visitedDict)
 
@@ -437,7 +447,6 @@ class Canvas(tk.Canvas, Scrollable):
 
             if getattr(node, 'expanded', True):
                 for child in node.getChilds():
-                    self.createEdge(item, child.item)
                     self._updatePositions(child, visitedDict)
 
 
@@ -646,6 +655,9 @@ class Item(object):
             bw = 2
             self.lift()
             # bc = 'Firebrick'
+        else:
+            self.lower()
+
         self.canvas.itemconfig(self.id, width=bw, outline=bc)
         self._notifySelectionListeners(value)
 
@@ -655,6 +667,9 @@ class Item(object):
     def lift(self):
         self.canvas.lift(self.id)
 
+    def lower(self):
+        self.canvas.lower(self.id)
+
 
 class TextItem(Item):
     """This class will serve to paint and store rectangle boxes with some text.
@@ -702,6 +717,11 @@ class TextItem(Item):
         super(TextItem, self).lift()
         self.canvas.lift(self.id_text)
 
+    def lower(self):
+        self.canvas.lower(self.id_text)
+        super(TextItem, self).lower()
+
+
 
 class TextBox(TextItem):
     def __init__(self, canvas, text, x, y, bgColor, textColor='black'):
